# Table of Contents

- [odata-integration](<./odata-integration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [OData Integration](<./OData-Integration.md>)
  - [Overview](<./OData-Integration/Overview.md>)
  - [Prerequisites](<./OData-Integration/Prerequisites.md>)
  - [Configuring the OData Integration](<./OData-Integration/Configuring-the-OData-Integration.md>)
  - [Enabling OData Sharing for a Saved Search](<./OData-Integration/Enabling-OData-Sharing-for-a-Saved-Search.md>)
  - [OData Endpoints](<./OData-Integration/OData-Endpoints.md>)
  - [Choosing an Endpoint for Your Use Case](<./OData-Integration/Choosing-an-Endpoint-for-Your-Use-Case.md>)
  - [Authentication](<./OData-Integration/Authentication.md>)
  - [Was this page helpful?](<./OData-Integration/Was-this-page-helpful.md>)
